/*
 * @(#)src/classes/sov/java/nio/channels/spi/AbstractSelectionKey.java, nio, asdev, 20070505 1.11
 * ===========================================================================
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 *
 * IBM SDK, Java(tm) 2 Technology Edition, v5.0
 * (C) Copyright IBM Corp. 1998, 2005. All Rights Reserved
 * ===========================================================================
 */

/*
 * ===========================================================================
 (C) Copyright Sun Microsystems Inc, 1992, 2004. All rights reserved.
 * ===========================================================================
 */

/*
 * Change activity:
 *
 * Reason  Date    Origin    Description
 * ------  ------  --------  -------------------------------------------------- 
 * 104278  170706  riclau    Make cancel() atomic
 */





package java.nio.channels.spi;

import java.nio.channels.*;


/**
 * Base implementation class for selection keys.
 *
 * <p> This class tracks the validity of the key and implements cancellation.
 *
 * @author Mark Reinhold
 * @author JSR-51 Expert Group
 * @version 1.11 03/12/19
 * @since 1.4
 */

public abstract class AbstractSelectionKey
    extends SelectionKey
{

    /**
     * Initializes a new instance of this class.  </p>
     */
    protected AbstractSelectionKey() { }

    private volatile boolean valid = true;

    public final boolean isValid() {
	return valid;
    }

    void invalidate() {                 // package-private
        valid = false;
    }

    private final Object cancelLock = new Object();               /*ibm@104278*/

    /**
     * Cancels this key.
     *
     * <p> If this key has not yet been cancelled then it is added to its
     * selector's cancelled-key set.  </p>
     */
    public final void cancel() {
        /* ibm@104278 - In order to make cancel() atomic, the fix for Sun bug 
         * 4744057 synchronizes on "this", which conflicts with our fix for 
         * 60554. We synchronize on something else to avoid deadlocking with 
         * the fix for 60554.
         */
        synchronized (cancelLock) {                               /*ibm@104278*/ 
            if (valid) {
                valid = false;                                        
                ((AbstractSelector)selector()).cancel(this);          
            }
        }                                                         /*ibm@104278*/ 
    }
}
